@@ -1503,12 +1503,7 @@ static void get_questinfo(int questnum)
 
 	/* Get the quest text */
 	init_flags = INIT_SHOW_TEXT | INIT_ASSIGN;
-#ifdef JP
-process_dungeon_file("q_info_j.txt", 0, 0, 0, 0);
-#else
 	process_dungeon_file("q_info.txt", 0, 0, 0, 0);
-#endif
-
 
 	/* Reset the old quest number */
 	p_ptr->inside_quest = old_quest;
@@ -2051,10 +2046,14 @@ static bool forge_ego_item(void)
 	int item;
 	int cost;
 	cptr q, s;
-	cptr basenm;
 	object_type *o_ptr;
 	object_type dummy;
 	object_type *q_ptr = &dummy;
+#ifdef JP
+	cptr basenm;
+#else
+	char basenm[MAX_NLEN];
+#endif
 
 	/* Get an item */
 #ifdef JP
@@ -2112,7 +2111,7 @@ static bool forge_ego_item(void)
 		basenm = get_object_name(o_ptr);
 		msg_format("%sɤΥɤޤ", basenm);
 #else
-		basenm = get_object_E_name(o_ptr);
+		object_desc(basenm, o_ptr, OD_NAME_ONLY);
 		msg_format("You do not have the gold to improve %s!", basenm);
 #endif
 		msg_print(NULL);
@@ -2126,7 +2125,7 @@ static bool forge_ego_item(void)
 	basenm = get_object_name(o_ptr);
 	msg_format("%d %sɤޤ", cost, basenm);
 #else
-	basenm = get_object_E_name(o_ptr);
+	object_desc(basenm, o_ptr, OD_NAME_ONLY);
 	msg_format("Improved %s for %d gold.", basenm, cost);
 #endif
 	msg_print(NULL);
@@ -2163,12 +2162,16 @@ static bool repair_broken_weapon(void)
 	int         item;
 	s32b        cost;
 	cptr        q, s;
-	cptr        basenm;
 	object_type *o_ptr;
 	object_type dummy;
 	object_type *q_ptr = &dummy;
 	object_kind *k_ptr, *old_k_ptr;
 	byte        new_sval;
+#ifdef JP
+	cptr basenm;
+#else
+	char basenm[MAX_NLEN];
+#endif
 
 	/* Get an item */
 #ifdef JP
@@ -2219,10 +2222,11 @@ static bool repair_broken_weapon(void)
 	/* Check if the player has enough money */
 	if (p_ptr->au < cost)
 	{
-		basenm = get_object_name(o_ptr);
 #ifdef JP
+		basenm = get_object_name(o_ptr);
 		msg_format("%sΥɤޤ", basenm);
 #else
+		object_desc(basenm, o_ptr, OD_NAME_ONLY);
 		msg_format("You do not have the gold to repair %s!", basenm);
 #endif
 		msg_print(NULL);
@@ -2294,10 +2298,11 @@ static bool repair_broken_weapon(void)
 #endif
 	}
 
-	basenm = get_object_name(q_ptr);
 #ifdef JP
+	basenm = get_object_name(q_ptr);
 	msg_format("%d%s˽ޤ", cost, basenm);
 #else
+	object_desc(basenm, q_ptr, OD_NAME_ONLY);
 	msg_format("Repaired into %s for %d gold.", basenm, cost);
 #endif
 	msg_print(NULL);
@@ -2781,7 +2786,7 @@ static void building_recharge_all(void)
 #ifdef JP
 		msg_print("ŶɬפϤޤ");
 #else
-		msg_print("nanka.");
+		msg_print("That doesn't need to be recharged.");
 #endif
 
 		msg_print(NULL);
@@ -2794,7 +2799,7 @@ static void building_recharge_all(void)
 #ifdef JP
 		msg_format("٤ƤΥƥƽŶˤϡ%d ɬפǤ", total_cost );
 #else
-		msg_format("nanka%d!",total_cost);
+		msg_format("You need %d gold to recharge all items!",total_cost);
 #endif
 		msg_print(NULL);
 		return;
@@ -2803,7 +2808,7 @@ static void building_recharge_all(void)
 #ifdef JP
 	if (!get_check(format("٤ƤΥƥ %d ǺƽŶޤ",  total_cost))) return;
 #else
-	if (!get_check(format("Nanka %d", total_cost))) return;
+	if (!get_check(format("Recharge all items for %d gold?", total_cost))) return;
 #endif
 
 	for (i = 0; i < INVEN_PACK; i++)
@@ -2847,7 +2852,7 @@ static void building_recharge_all(void)
 #ifdef JP
 	msg_format("%d ǺƽŶޤ", total_cost);
 #else
-	msg_format("nanka %d gold.", total_cost);
+	msg_format("You pay %d gold.", total_cost);
 #endif
 	msg_print(NULL);
 
