@@ -2,8 +2,6 @@
 
 #include "angband.h"
 
-#ifdef CHUUKEI
-
 #include <stdio.h>
 #include <stdarg.h>
 #include <ctype.h>
@@ -26,18 +24,26 @@
 #endif
 
 #define MAX_HOSTNAME 256
-#define RINGBUF_SIZE 65536*8
-#define FRESH_QUEUE_SIZE 1024
+#define RINGBUF_SIZE 1024*1024
+#define FRESH_QUEUE_SIZE 4096
+#ifdef WINDOWS
+#define WAIT 100
+#else
 #define WAIT 100*1000 /* ֥饦¦Υ(usñ) */
+#endif
 #define DEFAULT_DELAY 50
+#define RECVBUF_SIZE 1024
 
 static int sd; /* åȤΥեǥץ */
-static long epoch_time;  /* ϻ */
+static long epoch_time;  /* Хåեϻ */
 static long time_diff;   /* ץ쥤¦Ȥλ֤Τ(򸫤ʤǥ쥤ĴƤ) */
 static int browse_delay; /* ɽޤǤλ(100msñ)(δ֤˥饰ۼ) */
 static int server_port;
 static char server_name[MAX_HOSTNAME];
 
+static int movie_fd;
+
+static int movie_mode;
 
 #ifdef WINDOWS
 #define close closesocket
@@ -77,8 +83,32 @@ int recv(int s, char *buffer, size_t buflen, int flags)
 }
 #endif
 
+/*
+ * Original hooks
+ */
+static errr (*old_xtra_hook)(int n, int v);
+static errr (*old_curs_hook)(int x, int y);
+static errr (*old_bigcurs_hook)(int x, int y);
+static errr (*old_wipe_hook)(int x, int y, int n);
+static errr (*old_text_hook)(int x, int y, int n, byte a, cptr s);
+
+
+static void disable_chuukei_server(void)
+{
+	term *t = angband_term[0];
+
+	chuukei_server = FALSE;
+
+	t->xtra_hook = old_xtra_hook;
+	t->curs_hook = old_curs_hook;
+	t->bigcurs_hook = old_bigcurs_hook;
+	t->wipe_hook = old_wipe_hook;
+	t->text_hook = old_text_hook;
+}
+
+
 /* ANSI Cˤstaticѿ0ǽ뤬 */
-static errr init_chuukei(void)
+static errr init_buffer(void)
 {
 	fresh_queue.next = fresh_queue.tail = 0;
 	ring.wptr = ring.rptr = ring.inlen = 0;
@@ -93,7 +123,7 @@ static errr init_chuukei(void)
 static long get_current_time(void)
 {
 #ifdef WINDOWS
-	return GetTickCount() / 100;
+	return timeGetTime() / 100;
 #elif defined(MACINTOSH)
 	return TickCount();
 #else
@@ -111,11 +141,17 @@ static errr insert_ringbuf(char *buf)
 	int len;
 	len = strlen(buf) + 1; /* +1Ͻüʸʬ */
 
+	if (movie_mode)
+	{
+		fd_write(movie_fd, buf, len);
+		if (!chuukei_server) return 0;
+	}
+
 	/* Хåե򥪡С */
 	if (ring.inlen + len >= RINGBUF_SIZE)
 	{
-		chuukei_server = FALSE;
-		chuukei_client = FALSE;
+		if (chuukei_server) disable_chuukei_server();
+		else chuukei_client = FALSE;
 
 		prt("ХåեޤФȤ³Ǥޤ", 0, 0);
 		inkey();
@@ -182,7 +218,7 @@ void flush_ringbuf(void)
 		if (result <= 0)
 		{
 			/* ФȤ³ǡ */
-			chuukei_server = FALSE;
+			if (chuukei_server) disable_chuukei_server();
 
 			prt("ФȤ³Ǥޤ", 0, 0);
 			inkey();
@@ -198,29 +234,21 @@ void flush_ringbuf(void)
 		if (ring.inlen == 0) break;
 	}
 #else
-	struct timeval tv;
-
 	if (!chuukei_server) return;
 
 	if (ring.inlen == 0) return;
 
-	tv.tv_sec = 0;
-	tv.tv_usec = 0;
-
 	while (1)
 	{
-		struct timeval tmp_tv;
 		int result;
 
-		tmp_tv = tv;
-
 		/* åȤ˥ǡ񤭹뤫ɤĴ٤ */
 		result = OTSnd(ep, ring.buf + ring.rptr, ((ring.wptr > ring.rptr ) ? ring.wptr : RINGBUF_SIZE) - ring.rptr, 0);
 
 		if (result <= 0)
 		{
 			/* ФȤ³ǡ */
-			chuukei_server = FALSE;
+			if (chuukei_server) disable_chuukei_server();
 
 			prt("ФȤ³Ǥޤ", 0, 0);
 			inkey();
@@ -258,7 +286,8 @@ static int read_chuukei_prf(cptr prf_name)
 		/* ̾ */
 		if (!strncmp(buf, "server:", 7))
 		{
-			strncpy(server_name, buf + 7, MAX_HOSTNAME);
+			strncpy(server_name, buf + 7, MAX_HOSTNAME - 1);
+			server_name[MAX_HOSTNAME - 1] = '\0';
 		}
 
 		/* ݡֹ */
@@ -300,7 +329,7 @@ int connect_chuukei_server(char *prf_name)
 		return (-1);
 	}
 
-	if (init_chuukei() < 0)
+	if (init_buffer() < 0)
 	{
 		printf("Malloc error\n");
 		return (-1);
@@ -350,8 +379,6 @@ int connect_chuukei_server(char *prf_name)
 		return (-1);
 	}
 
-	epoch_time = get_current_time();
-
 	return (0);
 #else	/* MACINTOSH */
 	OSStatus err;
@@ -367,7 +394,7 @@ int connect_chuukei_server(char *prf_name)
 		return (-1);
 	}
 	
-	init_chuukei();
+	init_buffer();
 	
 	printf("server = %s\nport = %d\n", server_name, server_port);
 
@@ -476,13 +503,11 @@ static bool string_is_repeat(char *str, int len)
 	return (TRUE);
 }
 
-void send_text_to_chuukei_server(int x, int y, int len, int col, char *str)
+static errr send_text_to_chuukei_server(int x, int y, int len, byte col, cptr str)
 {
 	char buf[1024];
 	char buf2[1024];
 
-	if (!chuukei_server || Term != angband_term[0]) return;
-
 	strncpy(buf2, str, len);
 	buf2[len] = '\0';
 
@@ -503,99 +528,319 @@ void send_text_to_chuukei_server(int x, int y, int len, int col, char *str)
 	}
 
 	insert_ringbuf(buf);
+
+	return (*old_text_hook)(x, y, len, col, str);
 }
 
-void send_wipe_to_chuukei_server(int x, int y, int len)
+static errr send_wipe_to_chuukei_server(int x, int y, int len)
 {
 	char buf[1024];
 
-	if (!chuukei_server || Term != angband_term[0]) return;
-
 	sprintf(buf, "w%c%c%c", x+1, y+1, len);
 
 	insert_ringbuf(buf);
+
+	return (*old_wipe_hook)(x, y, len);
 }
 
-void send_xtra_to_chuukei_server(int n)
+static errr send_xtra_to_chuukei_server(int n, int v)
 {
 	char buf[1024];
 
-	if (!chuukei_server || Term != angband_term[0]) return;
-	sprintf(buf, "x%c", n+1);
-
-	insert_ringbuf(buf);
-
-	if (n == TERM_XTRA_FRESH)
+	if (n == TERM_XTRA_CLEAR || n == TERM_XTRA_FRESH || n == TERM_XTRA_SHAPE)
 	{
-		sprintf(buf, "d%ld", get_current_time() - epoch_time);
+		sprintf(buf, "x%c", n+1);
+		
 		insert_ringbuf(buf);
+		
+		if (n == TERM_XTRA_FRESH)
+		{
+			sprintf(buf, "d%ld", get_current_time() - epoch_time);
+			insert_ringbuf(buf);
+		}
 	}
+
+	/* Verify the hook */
+	if (!old_xtra_hook) return -1;
+
+	return (*old_xtra_hook)(n, v);
 }
 
-void send_curs_to_chuukei_server(int x, int y)
+static errr send_curs_to_chuukei_server(int x, int y)
 {
 	char buf[1024];
 
-	if (!chuukei_server || Term != angband_term[0]) return;
 	sprintf(buf, "c%c%c", x+1, y+1);
 
 	insert_ringbuf(buf);
+
+	return (*old_curs_hook)(x, y);
+}
+
+static errr send_bigcurs_to_chuukei_server(int x, int y)
+{
+	char buf[1024];
+
+	sprintf(buf, "C%c%c", x+1, y+1);
+
+	insert_ringbuf(buf);
+
+	return (*old_bigcurs_hook)(x, y);
+}
+
+
+/*
+ * Prepare z-term hooks to call send_*_to_chuukei_server()'s
+ */
+void prepare_chuukei_hooks(void)
+{
+	term *t0 = angband_term[0];
+
+	/* Save original z-term hooks */
+	old_xtra_hook = t0->xtra_hook;
+	old_curs_hook = t0->curs_hook;
+	old_bigcurs_hook = t0->bigcurs_hook;
+	old_wipe_hook = t0->wipe_hook;
+	old_text_hook = t0->text_hook;
+
+	/* Prepare z-term hooks */
+	t0->xtra_hook = send_xtra_to_chuukei_server;
+	t0->curs_hook = send_curs_to_chuukei_server;
+	t0->bigcurs_hook = send_bigcurs_to_chuukei_server;
+	t0->wipe_hook = send_wipe_to_chuukei_server;
+	t0->text_hook = send_text_to_chuukei_server;
+}
+
+
+/*
+ * Prepare z-term hooks to call send_*_to_chuukei_server()'s
+ */
+void prepare_movie_hooks(void)
+{
+	char buf[1024];
+	char tmp[80];
+
+	if (movie_mode)
+	{
+		movie_mode = 0;
+
+		if (!chuukei_server) disable_chuukei_server();
+		fd_close(movie_fd);
+#ifdef JP
+		msg_print("Ͽλޤ");
+#else
+		msg_print("Stopped recording.");
+#endif
+	}
+	else
+	{
+		sprintf(tmp, "%s.amv", player_base);
+#ifdef JP
+		if (get_string("ࡼӡϿե: ", tmp, 80))
+#else
+		if (get_string("Movie file name: ", tmp, 80))
+#endif
+		{
+			int fd;
+
+			path_build(buf, sizeof(buf), ANGBAND_DIR_USER, tmp);
+
+			fd = fd_open(buf, O_RDONLY);
+
+			/* Existing file */
+			if (fd >= 0)
+			{
+				char out_val[160];
+
+				/* Close the file */
+				(void)fd_close(fd);
+
+				/* Build query */
+#ifdef JP
+				(void)sprintf(out_val, "¸ե˾񤭤ޤ? (%s)", buf);
+#else
+				(void)sprintf(out_val, "Replace existing file %s? ", buf);
+#endif
+
+				/* Ask */
+				if (!get_check(out_val)) return;
+
+				movie_fd = fd_open(buf, O_WRONLY | O_TRUNC);
+			}
+			else
+			{
+				movie_fd = fd_make(buf, 0644);
+			}
+
+			if (!movie_fd)
+			{
+#ifdef JP
+				msg_print("ե򳫤ޤ");
+#else
+				msg_print("Can not open file.");
+#endif
+				return;
+			}
+
+			movie_mode = 1;
+			if (!chuukei_server) prepare_chuukei_hooks();
+
+			do_cmd_redraw();
+		}
+	}
+}
+
+
+static int handle_timestamp_data(int timestamp)
+{
+	long current_time = get_current_time();
+
+	/* 襭塼϶ɤ */
+	if (fresh_queue.tail == fresh_queue.next)
+	{
+		/* Хåե󥰤Ϥλ֤¸Ƥ */
+		epoch_time = current_time;
+		epoch_time += browse_delay;
+		epoch_time -= timestamp;
+		time_diff = current_time - timestamp;
+	}
+
+	/* 襭塼¸¸֤ʤ */
+	fresh_queue.time[fresh_queue.tail] = timestamp;
+	fresh_queue.tail ++;
+
+	/* 塼κǸãƬ᤹ */
+	fresh_queue.tail %= FRESH_QUEUE_SIZE;
+
+	if (fresh_queue.tail == fresh_queue.next)
+	{
+		/* 襭塼 */
+		prt("西ߥ󥰥塼ޤФȤ³Ǥޤ", 0, 0);
+		inkey();
+		close(sd);
+
+		return -1;
+	}
+
+	/* ץ쥤¦ȤΥǥ쥤Ĵ */
+	if (time_diff != current_time - timestamp)
+	{
+		long old_time_diff = time_diff;
+		time_diff = current_time - timestamp;
+		epoch_time -= (old_time_diff - time_diff);
+	}
+
+	/* Success */
+	return 0;
+}
+
+static int handle_movie_timestamp_data(int timestamp)
+{
+	static int initialized = FALSE;
+
+	/* 襭塼϶ɤ */
+	if (!initialized)
+	{
+		/* Хåե󥰤Ϥλ֤¸Ƥ */
+		epoch_time = get_current_time();
+		epoch_time += browse_delay;
+		epoch_time -= timestamp;
+		//time_diff = current_time - timestamp;
+		initialized = TRUE;
+	}
+
+	/* 襭塼¸¸֤ʤ */
+	fresh_queue.time[fresh_queue.tail] = timestamp;
+	fresh_queue.tail ++;
+
+	/* 塼κǸãƬ᤹ */
+	fresh_queue.tail %= FRESH_QUEUE_SIZE;
+
+	/* Success */
+	return 0;
 }
 
 static int read_sock(void)
 {
-	char buf[1024];
+	static char recv_buf[RECVBUF_SIZE];
+	static int remain_bytes = 0;
+	int recv_bytes;
 	int i;
 
-	for (i = 0;; i++)
+	/* ĤäǡθˤĤŤۿФǡ */
+	recv_bytes = recv(sd, recv_buf + remain_bytes, RECVBUF_SIZE - remain_bytes, 0);
+
+	if (recv_bytes <= 0)
+		return -1;
+
+	/* Ĥäǡ̤˺ɤǡ̤ɲ */
+	remain_bytes += recv_bytes;
+
+	for (i = 0; i < remain_bytes; i ++)
 	{
-		if (recv(sd, buf+i, 1, 0) <= 0) 
-			return -1;
-
-		if (buf[i] == '\0')
+		/* ǡΤ('\0')õ */
+		if (recv_buf[i] == '\0')
 		{
-			if (buf[0] == 'd')
-			{
-				int timestamp = atoi(buf + 1);
-				long current_time = get_current_time();
-
-				/* ǽλ֤¸Ƥ */
-				if (!fresh_queue.time[0])
-				{
-					epoch_time = current_time;
-					epoch_time += browse_delay;
-					epoch_time -= timestamp;
-					time_diff = current_time - timestamp;
-				}
-
-				fresh_queue.time[fresh_queue.tail] = timestamp;
-				fresh_queue.tail ++;
-
-				if (fresh_queue.tail == FRESH_QUEUE_SIZE)
-					fresh_queue.tail = 0;
-
-				/* ץ쥤¦ȤΥǥ쥤Ĵ */
-				if (time_diff > current_time - timestamp)
-				{
-					long old_time_diff = time_diff;
-					time_diff = current_time - timestamp;
-					epoch_time -= (old_time_diff - time_diff);
-				}
-
-				if (fresh_queue.tail == fresh_queue.next)
-				{
-					/* queue */
-					close(sd);
-					exit(1);
-				}
-
-			}
-
-			if (insert_ringbuf(buf) < 0) 
+			/* 'd'ǻϤޤǡ(ॹ)ξ
+			   襭塼¸Ƥ */
+			if ((recv_buf[0] == 'd') &&
+			    (handle_timestamp_data(atoi(recv_buf + 1)) < 0))
 				return -1;
-			return (i);
+
+			/* ǡ¸ */
+			if (insert_ringbuf(recv_buf) < 0) 
+				return -1;
+
+			/* ΥǡܹԤrecv_bufƬ˰ư */
+			memmove(recv_buf, recv_buf + i + 1, remain_bytes - i - 1);
+
+			remain_bytes -= (i+1);
+			i = 0;
 		}
 	}
+
+	return 0;
+}
+
+static int read_movie_file(void)
+{
+	static char recv_buf[RECVBUF_SIZE];
+	static int remain_bytes = 0;
+	int recv_bytes;
+	int i;
+
+	recv_bytes = read(movie_fd, recv_buf + remain_bytes, RECVBUF_SIZE - remain_bytes);
+
+	if (recv_bytes <= 0)
+		return -1;
+
+	/* Ĥäǡ̤˺ɤǡ̤ɲ */
+	remain_bytes += recv_bytes;
+
+	for (i = 0; i < remain_bytes; i ++)
+	{
+		/* ǡΤ('\0')õ */
+		if (recv_buf[i] == '\0')
+		{
+			/* 'd'ǻϤޤǡ(ॹ)ξ
+			   襭塼¸Ƥ */
+			if ((recv_buf[0] == 'd') &&
+			    (handle_movie_timestamp_data(atoi(recv_buf + 1)) < 0))
+				return -1;
+
+			/* ǡ¸ */
+			if (insert_ringbuf(recv_buf) < 0) 
+				return -1;
+
+			/* ΥǡܹԤrecv_bufƬ˰ư */
+			memmove(recv_buf, recv_buf + i + 1, remain_bytes - i - 1);
+
+			remain_bytes -= (i+1);
+			i = 0;
+		}
+	}
+
+	return 0;
 }
 
 
@@ -640,6 +885,23 @@ static bool get_nextbuf(char *buf)
 	return (TRUE);
 }
 
+/* ץ쥤ۥȤΥޥåפ礭Ȥ饤ȤΥޥåפꥵ */
+static void update_term_size(int x, int y, int len)
+{
+	int ox, oy;
+	int nx, ny;
+	Term_get_size(&ox, &oy);
+	nx = ox;
+	ny = oy;
+
+	/* Υå */
+	if (x + len > ox) nx = x + len;
+	/* Υå */
+	if (y + 1 > oy) ny = y + 1;
+
+	if (nx != ox || ny != oy) Term_resize(nx, ny);
+}
+
 static bool flush_ringbuf_client(void)
 {
 	char buf[1024];
@@ -677,6 +939,7 @@ static bool flush_ringbuf_client(void)
 #ifdef SJIS
 			euc2sjis(mesg);
 #endif
+			update_term_size(x, y, len);
 			(void)((*angband_term[0]->text_hook)(x, y, len, (byte)col, mesg));
 			strncpy(&Term->scr->c[y][x], mesg, len);
 			for (i = x; i < x+len; i++)
@@ -691,6 +954,7 @@ static bool flush_ringbuf_client(void)
 				mesg[i] = mesg[0];
 			}
 			mesg[i] = '\0';
+			update_term_size(x, y, len);
 			(void)((*angband_term[0]->text_hook)(x, y, len, (byte)col, mesg));
 			strncpy(&Term->scr->c[y][x], mesg, len);
 			for (i = x; i < x+len; i++)
@@ -700,12 +964,14 @@ static bool flush_ringbuf_client(void)
 			break;
 
 		case 's': /* ʸ */
+			update_term_size(x, y, 1);
 			(void)((*angband_term[0]->text_hook)(x, y, 1, (byte)col, mesg));
 			strncpy(&Term->scr->c[y][x], mesg, 1);
 			Term->scr->a[y][x] = col;
 			break;
 
 		case 'w':
+			update_term_size(x, y, len);
 			(void)((*angband_term[0]->wipe_hook)(x, y, len));
 			break;
 
@@ -715,8 +981,13 @@ static bool flush_ringbuf_client(void)
 			break;
 
 		case 'c':
+			update_term_size(x, y, 1);
 			(void)((*angband_term[0]->curs_hook)(x, y));
 			break;
+		case 'C':
+			update_term_size(x, y, 1);
+			(void)((*angband_term[0]->bigcurs_hook)(x, y));
+			break;
 		}
 	}
 
@@ -768,11 +1039,6 @@ void browse_chuukei()
 		if (!chuukei_client && fresh_queue.next == fresh_queue.tail ) break;
 	}
 #else
-	struct timeval tv;
-
-	tv.tv_sec = 0;
-	tv.tv_usec = WAIT;
-
 	Term_clear();
 	Term_fresh();
 	Term_xtra(TERM_XTRA_REACT, 0);
@@ -802,4 +1068,44 @@ void browse_chuukei()
 #endif /*MACINTOSH*/
 }
 
-#endif /* CHUUKEI */
+void prepare_browse_movie_aux(cptr filename)
+{
+	movie_fd = fd_open(filename, O_RDONLY);
+	
+	browsing_movie = TRUE;
+
+	init_buffer();
+}
+
+void prepare_browse_movie(cptr filename)
+{
+	char buf[1024];
+	path_build(buf, sizeof(buf), ANGBAND_DIR_USER, filename);
+
+	prepare_browse_movie_aux(buf);
+}
+
+void browse_movie(void)
+{
+	Term_clear();
+	Term_fresh();
+	Term_xtra(TERM_XTRA_REACT, 0);
+
+	while (read_movie_file() == 0)
+	{
+		while (fresh_queue.next != fresh_queue.tail)
+		{
+			if (!flush_ringbuf_client())
+			{
+				Term_xtra(TERM_XTRA_FLUSH, 0);
+
+				/* åȤ˥ǡƤ뤫ɤĴ٤ */
+#ifdef WINDOWS
+				Sleep(WAIT);
+#else
+				usleep(WAIT);
+#endif
+			}
+		}
+	}
+}
