@@ -1769,6 +1769,9 @@ static void py_attack_aux(int y, int x, int mode)
 	int             drain_left = MAX_VAMPIRIC_DRAIN;
 	u32b            f1, f2, f3; /* A massive hack -- life-draining weapons */
 
+	bool            backstab = FALSE;
+	bool            stab_fleeing = FALSE;
+
 
 	/* Disturb the player */
 	disturb(0, 0);
@@ -1783,16 +1786,18 @@ static void py_attack_aux(int y, int x, int mode)
 		if (one_in_(3) == 1) blows++;
 	}
 
-	if (p_ptr->pclass == CLASS_ROGUE)
+	if (p_ptr->pclass == CLASS_RANGER)
 	{
 		if (m_ptr->csleep && m_ptr->ml)
 		{
 			/* Can't backstab creatures that we can't see, right? */
-			sleeping_bonus = 10 + 2 * p_ptr->lev / 5;
+			sleeping_bonus = 200 + p_ptr->lev * 4;
+			backstab = TRUE;
 		}
 		else if (m_ptr->monfear && m_ptr->ml)
 		{
-			sleeping_bonus = 5 + p_ptr->lev / 5;
+			sleeping_bonus = 100 + p_ptr->lev * 2;
+			stab_fleeing = TRUE;
 		}
 	}
 
@@ -1963,9 +1968,13 @@ static void py_attack_aux(int y, int x, int mode)
 			else if (o_ptr->k_idx)
 			{
 #ifdef JP
-				msg_format("%s򹶷⤷", m_name);
+				if (backstab) msg_format("ʤˤ̲äƤ̵Ϥ%sͤɤ", m_name);
+				else if (stab_fleeing) msg_format("ƨ%s椫ͤɤ", m_name);
+				else msg_format("%s򹶷⤷", m_name);
 #else
-				msg_format("You hit %s.", m_name);
+				if (backstab) msg_format("You cruelly stab the helpless, sleeping %s!", m_name);
+				else if (stab_fleeing) msg_format("You backstab the fleeing %s!",  m_name);
+				else msg_format("You hit %s.", m_name);
 #endif
 
 				k = damroll(o_ptr->dd, o_ptr->ds);
@@ -2117,7 +2126,7 @@ static void py_attack_aux(int y, int x, int mode)
 #ifdef JP
 					msg_print("Ʈ̵ŨΥХꥢ¤");
 #else
-					msg_print("Nanka");
+					msg_print("The barrier is penetrated!");
 #endif
 			}
 			else
