@@ -49,7 +49,7 @@ void do_cmd_inven(void)
 		lbtokg1(p_ptr->total_weight) , lbtokg2(p_ptr->total_weight) ,
 		(int)((p_ptr->total_weight * 100) / ((adj_str_wgt[p_ptr->stat_ind[A_STR]] * 100) / 2)));
 #else
-	sprintf(out_val, "Inventory: carrying %d.%d pounds (%d%% of capacity). Command: ",
+	sprintf(out_val, "Inventory: carrying %ld.%ld pounds (%ld%% of capacity). Command: ",
 	    p_ptr->total_weight / 10, p_ptr->total_weight % 10,
 	    (p_ptr->total_weight * 100) / ((adj_str_wgt[p_ptr->stat_ind[A_STR]] * 100) / 2));
 #endif
@@ -123,7 +123,7 @@ void do_cmd_equip(void)
 		lbtokg1(p_ptr->total_weight) , lbtokg2(p_ptr->total_weight) ,
 		(int)((p_ptr->total_weight * 100) / ((adj_str_wgt[p_ptr->stat_ind[A_STR]] * 100) / 2)));
 #else
-	sprintf(out_val, "Equipment: carrying %d.%d pounds (%d%% of capacity). Command: ",
+	sprintf(out_val, "Equipment: carrying %ld.%ld pounds (%ld%% of capacity). Command: ",
 	    p_ptr->total_weight / 10, p_ptr->total_weight % 10,
 	    (p_ptr->total_weight * 100) / ((adj_str_wgt[p_ptr->stat_ind[A_STR]] * 100) / 2));
 #endif
@@ -221,7 +221,6 @@ void do_cmd_wield(void)
 	/* Check the slot */
 	slot = wield_slot(o_ptr);
 
-#ifdef JP
 	if ((o_ptr->tval == TV_RING) && inventory[INVEN_LEFT].k_idx &&
 		inventory[INVEN_RIGHT].k_idx)
 	{
@@ -241,7 +240,6 @@ void do_cmd_wield(void)
 			return;
 	}
 
-#endif
 	/* Prevent wielding into a cursed slot */
 	if (cursed_p(&inventory[slot]))
 	{
