@@ -103,19 +103,19 @@ static const char *spell_tips[MAX_REALM][32] =
 
 		"βݤ롣",
 		"ϤΥ󥸥ɤ餷ɤȾѤ롣",
+		"᤯˶ꡢ򷫤Ф",
 		"֡ŷ⡢ꡢ䵤ǤФ롣ˤѤ롣",
 		"//ܥȤ򶯤Ϥȯͤ롣",
 		"ڤ̣Τ빶򷫤Ф",
 		"֡®롣",
 		"Фƹ⤹롣",
-		"ƥŷ⡦бꡦ䵤ǽĤʤ褦ù롣",
 		"ߤΥӡġ",
 		"֡ˡɸϤAC夬ꡢܤȿǽϡΤ餺ͷ롣",
 
 		"ɶˤ줿Ϥ˲롣",
-		"᤯˶ꡢ򷫤Ф",
 		"ٰʥ󥹥ιɤХꥢĥ롣",
 		"βݤ®롣",
+		"ƥŷ⡦бꡦ䵤ǽĤʤ褦ù롣",
 		"󥹥ۯ۰Ȥݤ빶򤹤롣",
 		"̿Ψȥ᡼򶯲롣",
 		"ɸ潤򶯲롣",
@@ -127,112 +127,112 @@ static const char *spell_tips[MAX_REALM][32] =
 	},
 #else
 	{
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
+		"Detects all evil monsters in your vicinity.",
+		"Heals cut and HP a little.",
+		"Gives bonus to hit and AC for a few turns.",
+		"Removes fear.",
+		"Lights up nearby area and the inside of a room permanently.",
+		"Detects traps, doors, and stairs in your vicinity.",
+		"Heals cut and HP more.",
+		"Satisfies hunger.",
+		"Fires a beam of light which damages to light-sensitive monsters.",
+		"Removes normal curses from equipped items.",
 
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
+		"Heals cut, stun and HP greatly.",
+		"Fires a ball with holy power. Hurts evil monsters greatly, but don't effect good monsters.",
+		"Maps nearby area. Detects all monsters, traps, doors and stairs.",
+		"Gives resistance to fire and cold. These resistances can be added to which from equipment for more powerful resistances.",
+		"Attempts to charm a monster.",
+		"Gives aura which protect you from evil monster's physical attack.",
+		"Much powerful healing magic, and heals cut and stun completely.",
+		"Teleports all evil monsters in sight away unless resisted.",
+		"Fires a ball of light.",
+		"Sets a glyph on the floor beneath you. Monsters cannot attack you if you are on a glyph, but can try to break glyph.",
 
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
+		"Removes fear, and gives bonus to hit and 10 more HP for a while.",
+		"Removes normal and heavy curse from equipped items.",
+		"Gives resistance to fire, cold, electricity, acid and poison for a while. These resistances can be added to which from equipment for more powerful resistances.",
+		"Damages all evil monsters in sight.",
+		"Attempts to charm all monsters in sight.",
+		"Damages all evil monsters in sight, heals HP somewhat, and completely heals poison, fear, stun and cut status.",
+		"Blesses a weapon. Heavy cursed weapons resist it. Artifacts are disenchanted when blessing is failed."
+		"Restores all stats and experience.",
+		"Maps and lights whole dungeon level. Knows all objects location. And gives telepathy for a while.",
+		"*Identifies* an item.",
+		"The greatest healing magic. Heals all HP, cut and stun.",
+		"Damages all adjacent monsters with holy power. Damages and attempt to slow, stun, confuse, scare and freeze all monsters in sight. And heals HP.",
 	},
 	{
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
+		"Fires a weak bolt of magic.",
+		"Detects all monsters in your vicinity unless invisible.",
+		"Teleport short distance.",
+		"Detects traps, doors, and stairs in your vicinity.",
+		"Lights up nearby area and the inside of a room permanently.",
+		"Fires a beam which destroy traps and doors.",
+		"Teleport long distance.",
+		"Satisfies hunger.",
+		"Fires a ball of magic.",
+		"Recalls player from dungeon to town, or from town to the deepest level of dungeon.",
 
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
+		"Turns one rock square to mud.",
+		"Recharges staffs, wands or rods.",
+		"Maps nearby area.",
+		"Identifies an item. Or *Identifies* an item at lev 35.",
+		"Gives telepathy for a while.",
+		"Fires a beam of magic.",
+		"Hastes you for a while.",
+		"Teleports all monsters on the line away unless resisted.",
+		"Fires a magic rocket.",
+		"Eliminates an entire class of monster, exhausting you.  Powerful or unique monsters may resist.",
 
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
+		"Proves all monsters' alignment, HP, speed and their true character.",
+		"Teleport to up or down stairs in a moment.",
+		"Pulls a distant item close to you.",
+		"Detects all monsters, traps, doors, stairs, treasures and items in your vicinity.",
+		"Destroy everything in nearby area.",
+		"Maps and lights whole dungeon level. Knows all objects location. And gives telepathy for a while.",
+		"Teleports all monsters in sight away unless resisted.",
+		"Teleport to given location.",
+		"Turns an item into 1/3 of its value in gold.",
+		"Eliminates all nearby monsters, exhausting you.  Powerful or unique monsters may be able to resist.",
+		"Fires an extremely powerful huge ball of pure mana.",
+		"Becomes wraith form which gives ability to pass walls and makes all damages half."
 	},
 	{
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
+		"Gives regeneration ability for a while.",
+		"Attacks in 3 directions in one time.",
+		"Removes fear, and gives bonus to hit and 10 more HP for a while.",
+		"Steps close to a monster.",
+		"Gives resistance to fire, cold and electricity for a while. These resistances can be added to which from equipment for more powerful resistances.",
+		"Gives see everything in your sight for a while.",
+		"Attacks monster with your weapons normally, then move through counter side of the monster.",
+		"Fire a bolt of force.",
+		"Gives bonus to AC for a while.",
+		"Removes normal curses from equipped items.",
 
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
+		"Gives bonus to hit and HP, immunity to fear for a while. But decreases AC.",
+		"Shakes dungeon structure, and results in random swapping of floors and walls.",
+		"Steps close to a monster and attacks at a time.",
+		"Gives resistance to fire, cold, electricity, acid and poison for a while. These resistances can be added to which from equipment for more powerful resistances.",
+		"Fire a shot/allow/bolt strongly.",
+		"Attempts to attack with vorpal hit.",
+		"Hastes you for a while.",
+		"Attacks all adjacent monsters.",
+		"Fire a beam of inertia.",
+		"Gives resistance to magic, bonus to AC, resistance to confusion, blindness, reflection, free action and levitation for a while.",
 
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
-		"yet.",
+		"Removes all magics completely from any weapon or armor.",
+		"Gives aura which protect you from evil monster's physical attack.",
+		"Gives another bonus to hit and HP, immunity to fear for a while. Hastes you. But decreases AC.",
+		"Makes an equipment acid-proof.",
+		"Smashing a monster terribly.",
+		"Attempts to increase +to-hit, +to-dam of a weapon.",
+		"Attempts to increase +AC of an armor.",
+		"Attacks a monster and penetrates its barrier.",
+		"Double attacks at a time.",
+		"Fire a breath of inertia.",
+		"Makes current weapon an evil slayer.",
+		"Gives ultimate resistance, bonus to AC and speed."
 	},
 #endif
 };
@@ -1249,19 +1249,31 @@ static bool cast_musou_spell(int spell)
 		if (cave[y][x].m_idx)
 			py_attack(y, x);
 		else
+#ifdef JP
 			msg_print("϶ڤä");
+#else
+			msg_print("You attack the empty air.");
+#endif
 		y = py + ddy_cdd[(cdir + 7) % 8];
 		x = px + ddx_cdd[(cdir + 7) % 8];
 		if (cave[y][x].m_idx)
 			py_attack(y, x);
 		else
+#ifdef JP
 			msg_print("϶ڤä");
+#else
+			msg_print("You attack the empty air.");
+#endif
 		y = py + ddy_cdd[(cdir + 1) % 8];
 		x = px + ddx_cdd[(cdir + 1) % 8];
 		if (cave[y][x].m_idx)
 			py_attack(y, x);
 		else
+#ifdef JP
 			msg_print("϶ڤä");
+#else
+			msg_print("You attack the empty air.");
+#endif
 		break;
 	}
 	case 2: /* Heroism */
@@ -1312,19 +1324,26 @@ static bool cast_musou_spell(int spell)
 	case 11: /* Earthquake */
 		earthquake(py, px, 10);
 		break;
-	case 12: /* Resistance True */
+	case 12: /* Jump and Attack */
+		project_length = 5;
+		if (!get_aim_dir(&dir)) return FALSE;
+
+		project_hook(GF_JUMP_ATTACK, dir, 0, PROJECT_STOP | PROJECT_KILL);
+		project_length = 0;
+		break;
+	case 13: /* Resistance True */
 		(void)set_oppose_acid(p_ptr->oppose_acid + randint1(20) + 20);
 		(void)set_oppose_elec(p_ptr->oppose_elec + randint1(20) + 20);
 		(void)set_oppose_fire(p_ptr->oppose_fire + randint1(20) + 20);
 		(void)set_oppose_cold(p_ptr->oppose_cold + randint1(20) + 20);
 		(void)set_oppose_pois(p_ptr->oppose_pois + randint1(20) + 20);
 		break;
-	case 13: /* Aura Arrow */
+	case 14: /* Aura Arrow */
 		superb_shot = TRUE;
-		do_cmd_fire();
+		(void)do_cmd_fire();
 		superb_shot = FALSE;
 		break;
-	case 14: /* Fast Slicing */
+	case 15: /* Fast Slicing */
 		if (!get_rep_dir(&dir)) return FALSE;
 
 		y = py + ddy[dir];
@@ -1343,7 +1362,7 @@ static bool cast_musou_spell(int spell)
 			return FALSE;
 		}
 		break;
-	case 15: /* Haste Self */
+	case 16: /* Haste Self */
 		if (!p_ptr->fast)
 		{
 			(void)set_fast(randint1(20 + plev) + plev);
@@ -1353,7 +1372,7 @@ static bool cast_musou_spell(int spell)
 			(void)set_fast(p_ptr->fast + randint1(5));
 		}
 		break;
-	case 16: /* Whirlwind Attack */
+	case 17: /* Whirlwind Attack */
 		{
 			int y, x;
 			cave_type       *c_ptr;
@@ -1374,9 +1393,6 @@ static bool cast_musou_spell(int spell)
 			}
 		}
 		break;
-	case 17: /* Coating */
-		(void)coat_equip();
-		break;
 	case 18: /* Nanka() */
 		if (!get_aim_dir(&dir)) return FALSE;
 
@@ -1388,17 +1404,10 @@ static bool cast_musou_spell(int spell)
 	case 20: /* Remove Enchantment */
 		if(!mundane_spell(TRUE)) return FALSE;
 		break;
-	case 21: /* Jump and Attack */
-		project_length = 5;
-		if (!get_aim_dir(&dir)) return FALSE;
-
-		project_hook(GF_JUMP_ATTACK, dir, 0, PROJECT_STOP | PROJECT_KILL);
-		project_length = 0;
-		break;
-	case 22: /* Protection from Evil */
+	case 21: /* Protection from Evil */
 		(void)set_protevil(p_ptr->protevil + randint1(25) + 3 * p_ptr->lev);
 		break;
-	case 23: /* Battle Frenzy */
+	case 22: /* Battle Frenzy */
 		(void)set_shero(p_ptr->shero + randint1(25) + 25);
 		(void)hp_player(30);
 		(void)set_afraid(0);
@@ -1411,6 +1420,9 @@ static bool cast_musou_spell(int spell)
 			(void)set_fast(p_ptr->fast + randint1(5));
 		}
 		break;
+	case 23: /* Coating */
+		(void)coat_equip();
+		break;
 	case 24: /* Bombing Attack */
 		if (!get_rep_dir(&dir)) return FALSE;
 
