@@ -108,6 +108,9 @@ msg_print("ʤϺ𤷤");
 #endif
 
 			notice = TRUE;
+
+			/* Sniper */
+			if (p_ptr->concent) reset_concentration(TRUE);
 		}
 	}
 
@@ -353,6 +356,9 @@ msg_print("⤫˸롪");
 #endif
 
 			notice = TRUE;
+
+			/* Sniper */
+			if (p_ptr->concent) reset_concentration(TRUE);
 		}
 	}
 
@@ -1415,7 +1421,7 @@ bool set_tim_regen(int v)
 #ifdef JP
 msg_print("Ϥ");
 #else
-			msg_print("Nanka!");
+			msg_print("You feel yourself regenerating quickly!");
 #endif
 
 			notice = TRUE;
@@ -1430,7 +1436,7 @@ msg_print("Ϥ");
 #ifdef JP
 msg_print("᤯봶ʤʤä");
 #else
-			msg_print("Nanka.");
+			msg_print("You feel yourself regenerating slowly.");
 #endif
 
 			notice = TRUE;
@@ -1481,7 +1487,7 @@ bool set_tim_sh_fire(int v)
 #ifdef JP
 msg_print("ΤΥʤ줿");
 #else
-			msg_print("nanka!");
+			msg_print("You have enveloped by fiery aura!");
 #endif
 
 			notice = TRUE;
@@ -1496,7 +1502,7 @@ msg_print("ΤΥʤ줿");
 #ifdef JP
 msg_print("Υ餬ä");
 #else
-			msg_print("nanka.");
+			msg_print("Fiery aura disappeared.");
 #endif
 
 			notice = TRUE;
@@ -1544,7 +1550,7 @@ bool set_tim_sh_elec(int v)
 #ifdef JP
 msg_print("ΤŷΥʤ줿");
 #else
-			msg_print("nanka!");
+			msg_print("You have enveloped by electorical aura!");
 #endif
 
 			notice = TRUE;
@@ -1559,7 +1565,7 @@ msg_print("ΤŷΥʤ줿");
 #ifdef JP
 msg_print("ŷΥ餬ä");
 #else
-			msg_print("nanka.");
+			msg_print("Electorical aura disappeared.");
 #endif
 
 			notice = TRUE;
@@ -1607,7 +1613,7 @@ bool set_tim_sh_cold(int v)
 #ifdef JP
 msg_print("Τ䵤Υʤ줿");
 #else
-			msg_print("nanka!");
+			msg_print("You have enveloped by icy aura!");
 #endif
 
 			notice = TRUE;
@@ -1622,7 +1628,7 @@ msg_print("Τ䵤Υʤ줿");
 #ifdef JP
 msg_print("䵤Υ餬ä");
 #else
-			msg_print("nanka.");
+			msg_print("Icy aura disappeared.");
 #endif
 
 			notice = TRUE;
@@ -2100,6 +2106,9 @@ msg_print("褦Ƭˤ롣");
 
 		/* Notice */
 		notice = TRUE;
+
+		/* Sniper */
+		if (p_ptr->concent) reset_concentration(TRUE);
 	}
 
 	/* Decrease cut */
