@@ -25,7 +25,7 @@ struct element_power
 	const char *name;
 };
 
-static char *element_title[MAX_ELEMENTS] =
+static cptr element_title[MAX_ELEMENTS] =
 {
 #ifdef JP
 	"",
@@ -64,7 +64,7 @@ static int element_type[MAX_ELEMENTS][3] =
 #endif
 };
 
-static char *element_name[MAX_ELEMENTS][3] =
+static cptr element_name[MAX_ELEMENTS][3] =
 {
 #ifdef JP
 	{"б", "ץ饺", ""},
@@ -76,8 +76,14 @@ static char *element_name[MAX_ELEMENTS][3] =
 	{"", "ե", ""},
 	{"", "۷", ""},
 #else
-
 	{"Fire", "Plasma", "Holy"},
+	{"Ice", "Inartia", "Time"},
+	{"Lightning", "Light", "Mana"},
+	{"Acid", "Water", "Disin"},
+	{"Dark", "Nether", "Evil"},
+	{"Conf", "Nexus", "Chaos"},
+	{"Shard", "Force", "Meteo"},
+	{"Poison", "Drain", "Disenchant"},
 #endif
 };
 
@@ -125,7 +131,40 @@ struct element_tips_data element_tips[MAX_ELEMENT_POWERS] =
 	{ "%sεʵġ",
 	  {"","ֵž","","ʬ", "ٵ","","",""} },
 #else
-	{"yet.",-1},
+	{ "Fire a weak bolt of %s.",
+	  {"fire","ice","lightning","acid", "dark","confusion","shard","poison"} },
+	{ "Detects monsters.",
+	  {NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL} },
+	{ "Gives feeling of an item.",
+	  {NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL} },
+	{ "Heals HP and wounds a little.",
+	  {NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL} },
+	{ "Fire a bolt of %s.",
+	  {"plasma","inertia","light","water", "nether","nexus","force","drain life"} },
+	{ "Detects magic devices.",
+	  {NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL} },
+	{ "Fire a short and strong beam of %s.",
+	  {"fire","ice","lightning","acid", "dark","confusion","shard","poison"} },
+	{ "Fire a ball of %s.",
+	  {"fire","ice","lightning","acid", "dark","confusion","shard","poison"} },
+	{ "Fire a breath of %s.",
+	  {"plasma","inertia","light","water", "nether","nexus","force","drain life"} },
+	{ "Erase a monster unless it resists %s.",
+	  {"fire","ice","lightning","acid", "dark","confusion","shard","poison"} },
+	{ "Fire a bolt of %s.",
+	  {"holy fire","time","mana","disintegrate", "hell fire","chaos","meteo","disenchant"} },
+	{ "Inflict all monsters with %s damage.",
+	  {"fire","ice","lightning","acid", "dark","confusion","shard","poison"} },
+	{ "Fire a ball of %s.",
+	  {"plasma","inertia","light","water", "nether","nexus","force","drain life"} },
+	{ "Fire some bolts of %s toward random direction.",
+	  {"fire","ice","lightning","acid", "dark","confusion","shard","poison"} },
+	{ "Fire a large ball of %s.",
+	  {"plasma","inertia","light","water", "nether","nexus","force","drain life"} },
+	{ "Fire a breath of %s.",
+	  {"fire","ice","lightning","acid", "dark","confusion","shard","poison"} },
+	{ "Fire a huge ball of %s.",
+	  {"holy fire","time","mana","disintegrate", "hell fire","chaos","meteo","disenchant"} },
 #endif
 };
 
@@ -236,7 +275,7 @@ bool elemental_genocide(int m_idx)
 	return TRUE;
 }
 
-void element_info(char *p, int power)
+static void element_info(char *p, int power)
 {
 	int plev = p_ptr->lev;
 
