@@ -114,6 +114,16 @@ void get_table_name(char *out_string)
 	get_rnd_line("aname_j.txt", 2, Syllable);
 	strcat(out_string, Syllable);
 	strcat(out_string, "");
+#else
+#if 1
+	char Syllable[80];
+
+	strcpy(out_string, "'");
+	get_rnd_line("aname.txt", 1, Syllable);
+	strcat(out_string, Syllable);
+	get_rnd_line("aname.txt", 2, Syllable);
+	strcat(out_string, Syllable);
+	strcat(out_string, "'");
 #else
 	int testcounter = randint1(3) + 1;
 
@@ -139,6 +149,7 @@ void get_table_name(char *out_string)
 
 	strcat(out_string, "'");
 #endif
+#endif
 
 
 	out_string[18] = '\0';
@@ -2009,6 +2020,10 @@ void object_desc(char *buf, object_type *o_ptr, u32b mode)
 		/* Launcher multiplier */
 		avgdam *= tmul;
 		avgdam /= (100 * 10);
+
+		/* Get extra damage from concentration */
+		if (p_ptr->concent) avgdam = boost_concentration_damage(avgdam);
+	
 		if (avgdam < 0) avgdam = 0;
 
 		/* Display (shot damage/ avg damage) */
