@@ -389,7 +389,7 @@ static void try_door(int y, int x)
 
 
 /* Place quest monsters */
-void place_quest_monsters(void)
+static void place_quest_monsters(void)
 {
 	int i;
 
@@ -499,7 +499,7 @@ static void gen_caverns_and_lakes(void)
 		}
 	}
 
-	if (one_in_(DUN_CAV1 / (dun_level + DUN_CAV2)) && !dun->empty_level &&
+	if (one_in_(CAVE_LEVEL - (dun_level / 10)) && !dun->empty_level &&
 	    !dun->laketype && !dun->destroyed && (dun_level >= MIN_CAVERN))
 	{
 		dun->cavern = TRUE;
@@ -1018,12 +1018,7 @@ static void quest_gen(void)
 	get_mon_num_prep(get_monster_hook(), NULL);
 
 	init_flags = INIT_CREATE_DUNGEON | INIT_ASSIGN;
-#ifdef JP
-process_dungeon_file("q_info_j.txt", 0, 0, MAX_HGT, MAX_WID);
-#else
 	process_dungeon_file("q_info.txt", 0, 0, MAX_HGT, MAX_WID);
-#endif
-
 }
 
 /* Make a real level */
