@@ -158,7 +158,7 @@ void delete_monster_idx(int i)
 
 	monster_race *r_ptr = &r_info[m_ptr->r_idx];
 
-	s16b this_o_idx, next_o_idx = 0;
+	s16b this_o_idx, next_o_idx;
 
 
 	/* Get location */
@@ -195,8 +195,10 @@ void delete_monster_idx(int i)
 		/* Acquire next object */
 		next_o_idx = o_ptr->next_o_idx;
 
-		/* Hack -- efficiency */
-		o_ptr->held_m_idx = 0;
+		/*
+		 * o_ptr->held_m_idx is needed in delete_object_idx()
+		 * to prevent calling lite_spot()
+		 */
 
 		/* Delete the object */
 		delete_object_idx(this_o_idx);
@@ -246,7 +248,7 @@ static void compact_monsters_aux(int i1, int i2)
 
 	monster_type *m_ptr;
 
-	s16b this_o_idx, next_o_idx = 0;
+	s16b this_o_idx, next_o_idx;
 
 
 	/* Do nothing */
@@ -1425,7 +1427,7 @@ void update_mon(int m_idx, bool full)
 	if (d <= MAX_SIGHT)
 	{
 		/* Basic telepathy */
-		if (p_ptr->telepathy)
+		if ((p_ptr->telepathy) || (p_ptr->concent >= CONCENT_TELE_THRESHOLD))
 		{
 			/* Empty mind, no telepathy */
 			if (r_ptr->flags2 & (RF2_EMPTY_MIND))
@@ -1471,7 +1473,7 @@ void update_mon(int m_idx, bool full)
 			bool do_cold_blood = FALSE;
 
 			/* Use "radar eye" */
-			if (p_ptr->tim_radar > 0)
+			if ((p_ptr->tim_radar > 0) || (p_ptr->concent >= CONCENT_RADAR_THRESHOLD))
 			{
 				/* Easy to see */
 				easy = flag = TRUE;
@@ -1685,7 +1687,6 @@ bool place_monster_one(int y, int x, int r_idx, bool slp, bool friendly, bool pe
 	/* Verify location */
 	if (!in_bounds(y, x)) return (FALSE);
 
-	/* Require empty space (if not ghostly) */
 	/* Require empty space (if not ghostly) */
 	if (!cave_empty_bold2(y, x) &&
 	    !((r_ptr->flags2 & RF2_PASS_WALL) &&
@@ -1745,10 +1746,6 @@ bool place_monster_one(int y, int x, int r_idx, bool slp, bool friendly, bool pe
 #else
 			if (cheat_hear) msg_format("Deep Unique (%s).", name);
 #endif
-
-
-			/* Boost rating by twice delta-depth */
-			rating += (r_ptr->level - dun_level) * 2;
 		}
 
 		/* Normal monsters */
@@ -1760,10 +1757,6 @@ bool place_monster_one(int y, int x, int r_idx, bool slp, bool friendly, bool pe
 #else
 			if (cheat_hear) msg_format("Deep Monster (%s).", name);
 #endif
-
-
-			/* Boost rating by delta-depth */
-			rating += (r_ptr->level - dun_level);
 		}
 	}
 
@@ -1973,7 +1966,7 @@ bool place_monster_one(int y, int x, int r_idx, bool slp, bool friendly, bool pe
 			o_ptr = choose_warning_item();
 			if (o_ptr)
 			{
-				object_desc(o_name, o_ptr, FALSE, 0);
+				object_desc(o_name, o_ptr, OD_OMIT_PREFIX | OD_NAME_ONLY);
 #ifdef JP
 				msg_format("%s%sä", o_name, color);
 #else
@@ -1996,6 +1989,76 @@ bool place_monster_one(int y, int x, int r_idx, bool slp, bool friendly, bool pe
 }
 
 
+/*
+ * Improved version of scatter() for place_monster
+ * Originally from Hengband
+ */
+
+#define MON_SCAT_MAXD 10
+
+static bool mon_scatter(int *yp, int *xp, int y, int x, int max_dist)
+{
+	int place_x[MON_SCAT_MAXD];
+	int place_y[MON_SCAT_MAXD];
+	int num[MON_SCAT_MAXD];
+	int i;
+	int nx, ny;
+
+	if (max_dist >= MON_SCAT_MAXD)
+		return FALSE;
+
+	for (i = 0; i < MON_SCAT_MAXD; i++)
+		num[i] = 0;
+
+	for (nx = x - max_dist; nx <= x + max_dist; nx++)
+		for (ny = y - max_dist; ny <= y + max_dist; ny++)
+		{
+			/* Ignore annoying locations */
+			if (!in_bounds(ny, nx)) continue;
+
+			/* Require "line of sight" */
+			if (!los(y, x, ny, nx)) continue;
+
+			/* Walls and Monsters block flow */
+			if (!cave_empty_bold2(ny, nx)) continue;
+
+			/* Hack -- no summon on glyph of warding */
+			if (cave[ny][nx].feat == FEAT_GLYPH) continue;
+			if (cave[ny][nx].feat == FEAT_MINOR_GLYPH) continue;
+
+			/* ... nor on the Pattern */
+			if ((cave[ny][nx].feat >= FEAT_PATTERN_START) &&
+			    (cave[ny][nx].feat <= FEAT_PATTERN_XTRA2))
+				continue;
+
+			i = distance(y, x, ny, nx);
+
+			if (i > max_dist)
+				continue;
+
+			num[i]++;
+
+			/* random swap */
+			if(one_in_(num[i]))
+			{
+				place_x[i] = nx;
+				place_y[i] = ny;
+			}
+		}
+
+	i = 0;
+	while (i < MON_SCAT_MAXD && 0 == num[i])
+		i++;
+	if (i >= MON_SCAT_MAXD)
+		return FALSE;
+
+	*xp = place_x[i];
+	*yp = place_y[i];
+
+	return TRUE;
+}
+
+
 /*
  * Maximum size of a group of monsters
  */
@@ -2009,17 +2072,16 @@ static bool place_monster_group(int y, int x, int r_idx, bool slp, bool friendly
 {
 	monster_race *r_ptr = &r_info[r_idx];
 
-	int old, n, i;
-	int total = 0, extra = 0;
+	int n, i;
+	int extra = 0;
 
-	int hack_n = 0;
+	int hack_n;
 
 	int hack_y[GROUP_MAX];
 	int hack_x[GROUP_MAX];
 
-
 	/* Pick a group size */
-	total = randint1(13);
+	int total = randint1(13);
 
 	/* Hard monsters, small groups */
 	if (r_ptr->level > dun_level)
@@ -2048,9 +2110,6 @@ static bool place_monster_group(int y, int x, int r_idx, bool slp, bool friendly
 	if (total > GROUP_MAX) total = GROUP_MAX;
 
 
-	/* Save the rating */
-	old = rating;
-
 	/* Start on the monster */
 	hack_n = 1;
 	hack_x[0] = x;
@@ -2084,9 +2143,6 @@ static bool place_monster_group(int y, int x, int r_idx, bool slp, bool friendly
 		}
 	}
 
-	/* Hack -- restore the rating */
-	rating = old;
-
 
 	/* Success */
 	return (TRUE);
@@ -2618,7 +2674,7 @@ static bool summon_specific_okay(int r_idx)
 		case SUMMON_ANIMAL_RANGER:
 		{
 			okay = ((r_ptr->flags3 & (RF3_ANIMAL)) &&
-			       (strchr("abcflqrwBCIJKMRS", r_ptr->d_char)) &&
+			       (my_strchr("abcflqrwBCIJKMRS", r_ptr->d_char)) &&
 			       !(r_ptr->flags3 & (RF3_DRAGON)) &&
 			       !(r_ptr->flags3 & (RF3_EVIL)) &&
 					 !(r_ptr->flags3 & (RF3_UNDEAD)) &&
@@ -2700,35 +2756,10 @@ static bool summon_specific_okay(int r_idx)
  */
 bool summon_specific(int who, int y1, int x1, int lev, int type, bool group, bool friendly, bool pet)
 {
-	int i, x, y, r_idx;
+	int x, y, r_idx;
 
 	/* Look for a location */
-	for (i = 0; i < 20; ++i)
-	{
-		/* Pick a distance */
-		int d = (i / 15) + 1;
-
-		/* Pick a location */
-		scatter(&y, &x, y1, x1, d, 0);
-
-		/* Require "empty" floor grid */
-		if (!cave_empty_bold(y, x)) continue;
-
-		/* Hack -- no summon on glyph of warding */
-		if (cave[y][x].feat == FEAT_GLYPH) continue;
-		if (cave[y][x].feat == FEAT_MINOR_GLYPH) continue;
-
-		/* ... nor on the Pattern */
-		if ((cave[y][x].feat >= FEAT_PATTERN_START) &&
-			 (cave[y][x].feat <= FEAT_PATTERN_XTRA2))
-			continue;
-
-		/* Okay */
-		break;
-	}
-
-	/* Failure */
-	if (i == 20) return (FALSE);
+	if (!mon_scatter(&y, &x, y1, x1, 2)) return FALSE;
 
 	/* Save the summoner */
 	summon_specific_who = who;
@@ -2758,8 +2789,7 @@ bool summon_specific(int who, int y1, int x1, int lev, int type, bool group, boo
 /* A "dangerous" function, creates a pet of the specified type */
 bool summon_named_creature(int oy, int ox, int r_idx, bool slp, bool group_ok, bool pet)
 {
-	int i, x, y;
-	bool success = FALSE;
+	int x, y;
 
 	/* Paranoia */
 	/* if (!r_idx) return; */
@@ -2767,26 +2797,10 @@ bool summon_named_creature(int oy, int ox, int r_idx, bool slp, bool group_ok, b
 	/* Prevent illegal monsters */
 	if (r_idx >= max_r_idx) return FALSE;
 
-	/* Try 10 times */
-	for (i = 0; i < 10; i++)
-	{
-		int d = 1;
+	if (!mon_scatter(&y, &x, oy, ox, 2)) return FALSE;
 
-		/* Pick a location */
-		scatter(&y, &x, oy, ox, d, 0);
-
-		/* Require empty grids */
-		if (!cave_empty_bold(y, x)) continue;
-
-		/* Place it (allow groups) */
-		if (place_monster_aux(y, x, r_idx, slp, group_ok, FALSE, pet))
-		{
-			success = TRUE;
-			break;
-		}
-	}
-
-	return success;
+	/* Place it (allow groups) */
+	return place_monster_aux(y, x, r_idx, slp, group_ok, FALSE, pet);
 }
 
 
@@ -2799,32 +2813,18 @@ bool multiply_monster(int m_idx, bool clone, bool friendly, bool pet)
 {
 	monster_type	*m_ptr = &m_list[m_idx];
 
-	int			i, y, x;
+	int y, x;
 
-	bool result = FALSE;
+	if (!mon_scatter(&y, &x, m_ptr->fy, m_ptr->fx, 1)) return FALSE;
 
-	/* Try up to 18 times */
-	for (i = 0; i < 18; i++)
-	{
-		int d = 1;
+	/* Create a new monster (awake, no groups) */
+	if (!place_monster_aux(y, x, m_ptr->r_idx, FALSE, FALSE, friendly, pet))
+		return FALSE;
 
-		/* Pick a location */
-		scatter(&y, &x, m_ptr->fy, m_ptr->fx, d, 0);
+	/* Hack -- Transfer "clone" flag */
+	if (clone || (m_ptr->smart & SM_CLONED)) m_list[hack_m_idx_ii].smart |= SM_CLONED;
 
-		/* Require an "empty" floor grid */
-		if (!cave_empty_bold(y, x)) continue;
-
-		/* Create a new monster (awake, no groups) */
-		result = place_monster_aux(y, x, m_ptr->r_idx, FALSE, FALSE, friendly, pet);
-
-		/* Done */
-		break;
-	}
-
-	if (clone && result) m_list[hack_m_idx_ii].smart |= SM_CLONED;
-
-	/* Result */
-	return (result);
+	return TRUE;
 }
 
 
@@ -2870,7 +2870,7 @@ void message_pain(int m_idx, int dam)
 
 
 	/* Mushrooms, Eyes, Jellies, Molds, Vortices, Worms, Quylthulgs */
-	if (strchr(",ejmvwQ", r_ptr->d_char))
+	if (my_strchr(",ejmvwQ", r_ptr->d_char))
 	{
 #ifdef JP
 		if (percentage > 95)
@@ -2908,7 +2908,7 @@ void message_pain(int m_idx, int dam)
 
 
 	/* Fish */
-	else if (strchr("~", r_ptr->d_char))
+	else if (my_strchr("~", r_ptr->d_char))
 	{
 		if (percentage > 95)
 #ifdef JP
@@ -2963,7 +2963,7 @@ msg_format("%^sϤˤ㤰ˤڻ", m_name);
 
 
 	/* Golems, Walls, Doors, Stairs */
-	else if (strchr("g#+<>", r_ptr->d_char))
+	else if (my_strchr("g#+<>", r_ptr->d_char))
 	{
 		if (percentage > 95)
 #ifdef JP
@@ -3018,7 +3018,7 @@ msg_format("%^sϤ㤯ˤʤä", m_name);
 
 
 	/* Snakes, Hydrae, Reptiles, Mimics */
-	else if (strchr("JMR", r_ptr->d_char) || !isalpha(r_ptr->d_char))
+	else if (my_strchr("JMR", r_ptr->d_char) || !isalpha(r_ptr->d_char))
 	{
 		if (percentage > 95)
 #ifdef JP
@@ -3073,7 +3073,7 @@ msg_format("%^sϤˤ㤰ˤڻ", m_name);
 
 
 	/* Felines */
-	else if (strchr("f", r_ptr->d_char))
+	else if (my_strchr("f", r_ptr->d_char))
 	{
 		if (percentage > 95)
 #ifdef JP
@@ -3128,7 +3128,7 @@ msg_format("%sϰĤФ", m_name);
 
 
 	/* Ants, Centipedes, Flies, Insects, Beetles, Spiders */
-	else if (strchr("acFIKS", r_ptr->d_char))
+	else if (my_strchr("acFIKS", r_ptr->d_char))
 	{
 		if (percentage > 95)
 #ifdef JP
@@ -3183,7 +3183,7 @@ msg_format("%^sϥԥԥҤĤä", m_name);
 
 
 	/* Birds */
-	else if (strchr("B", r_ptr->d_char))
+	else if (my_strchr("B", r_ptr->d_char))
 	{
 		if (percentage > 95)
 #ifdef JP
@@ -3238,7 +3238,7 @@ msg_format("%^sϥĤ", m_name);
 
 
 	/* Dragons, Demons, High Undead */
-	else if (strchr("duDLUW", r_ptr->d_char))
+	else if (my_strchr("duDLUW", r_ptr->d_char))
 	{
 		if (percentage > 95)
 #ifdef JP
@@ -3293,7 +3293,7 @@ msg_format("%^sϼ塹ʤä", m_name);
 
 
 	/* Skeletons */
-	else if (strchr("s", r_ptr->d_char))
+	else if (my_strchr("s", r_ptr->d_char))
 	{
 		if (percentage > 95)
 #ifdef JP
@@ -3348,7 +3348,7 @@ msg_format("%^sϥä", m_name);
 
 
 	/* Zombies */
-	else if (strchr("z", r_ptr->d_char))
+	else if (my_strchr("z", r_ptr->d_char))
 	{
 		if (percentage > 95)
 #ifdef JP
@@ -3403,7 +3403,7 @@ msg_format("%^sϤᤤ", m_name);
 
 
 	/* Ghosts */
-	else if (strchr("G", r_ptr->d_char))
+	else if (my_strchr("G", r_ptr->d_char))
 	{
 		if (percentage > 95)
 #ifdef JP
@@ -3458,7 +3458,7 @@ msg_format("%^sϤˤᤤ", m_name);
 
 
 	/* Dogs and Hounds */
-	else if (strchr("CZ", r_ptr->d_char))
+	else if (my_strchr("CZ", r_ptr->d_char))
 	{
 #ifdef JP
 		if (percentage > 95)
@@ -3495,7 +3495,7 @@ msg_format("%^sϤˤᤤ", m_name);
 	}
 
 	/* One type of monsters (ignore,squeal,shriek) */
-	else if (strchr("Xbilqrt", r_ptr->d_char))
+	else if (my_strchr("Xbilqrt", r_ptr->d_char))
 	{
 #ifdef JP
 		if (percentage > 95)
@@ -3711,7 +3711,7 @@ bool player_place(int y, int x)
  */
 void monster_drop_carried_objects(monster_type *m_ptr)
 {
-	s16b this_o_idx, next_o_idx = 0;
+	s16b this_o_idx, next_o_idx;
 	object_type forge;
 	object_type *o_ptr;
 	object_type *q_ptr;
@@ -3726,15 +3726,15 @@ void monster_drop_carried_objects(monster_type *m_ptr)
 		/* Acquire next object */
 		next_o_idx = o_ptr->next_o_idx;
 
-		/* Paranoia */
-		o_ptr->held_m_idx = 0;
-
 		/* Get local object */
 		q_ptr = &forge;
 
 		/* Copy the object */
 		object_copy(q_ptr, o_ptr);
 
+		/* Forget monster */
+		q_ptr->held_m_idx = 0;
+
 		/* Delete the object */
 		delete_object_idx(this_o_idx);
 
