@@ -42,7 +42,7 @@ static void monst_breath_monst(int m_idx, int y, int x, int typ, int dam_hp, int
  */
 static void monst_bolt_monst(int m_idx, int y, int x, int typ, int dam_hp)
 {
-	u16b flg = PROJECT_STOP | PROJECT_KILL;
+	u16b flg = PROJECT_STOP | PROJECT_KILL | PROJECT_REFLECTABLE;
 
 	(void)project(m_idx, 0, y, x, dam_hp, typ, flg);
 }
@@ -56,10 +56,10 @@ static void monst_bolt_monst(int m_idx, int y, int x, int typ, int dam_hp)
  */
 bool monst_spell_monst(int m_idx)
 {
-	int y = 0, x = 0;
+	int y, x;
 	int i, k, t_idx;
 	int chance, thrown_spell, count = 0;
-	int rlev, dam = 0;
+	int rlev, dam;
 
 	byte spell[96], num = 0;
 
@@ -121,14 +121,21 @@ bool monst_spell_monst(int m_idx)
 		/* Monster must be 'an enemy' */
 		if (!are_enemies(m_ptr, t_ptr)) continue;
 
+		/* Extract the racial spell flags */
+		f4 = r_ptr->flags4;
+		f5 = r_ptr->flags5;
+		f6 = r_ptr->flags6;
+
 		/* Monster must be projectable */
 		if (!projectable(t_ptr->fy, t_ptr->fx, m_ptr->fy, m_ptr->fx))
 		{
 			if (m_ptr->target_y && 
 			    (m_ptr->target_y == t_ptr->fy) && (m_ptr->target_x == t_ptr->fx))
 				{
+					/*
 					y = m_ptr->target_y;
 					x = m_ptr->target_x;
+					*/
 					f4 &= (RF4_INDIRECT_MASK);
 					f5 &= (RF5_INDIRECT_MASK);
 					f6 &= (RF6_INDIRECT_MASK);
@@ -147,11 +154,6 @@ bool monst_spell_monst(int m_idx)
 		/* Extract the monster level */
 		rlev = ((r_ptr->level >= 1) ? r_ptr->level : 1);
 
-		/* Extract the racial spell flags */
-		f4 = r_ptr->flags4;
-		f5 = r_ptr->flags5;
-		f6 = r_ptr->flags6;
-
 		/* Disallow blink unless close */
 		if ((distance(m_ptr->fy, m_ptr->fx, y, x) > 1) || !randint0(3)) f6 &= ~(RF6_BLINK);
 
@@ -183,14 +185,7 @@ bool monst_spell_monst(int m_idx)
 		}
 
 		/* Find another target if no spells available */
-		if (!f4 && !f5 && !f6)
-		{
-			f4 = r_ptr->flags4;
-			f5 = r_ptr->flags5;
-			f6 = r_ptr->flags6;
-
-			continue;
-		}
+		if (!f4 && !f5 && !f6) continue;
 
 		/* Hack -- allow "desperate" spells */
 		if ((r_ptr->flags2 & RF2_SMART) &&
@@ -322,6 +317,7 @@ bool monst_spell_monst(int m_idx)
 						if (blind) msg_format("%^s shoots something.", m_name);
 						else msg_format("%^s fires a rocket at %s.", m_name, t_name);
 #endif
+						sound(SOUND_ROCKET);
 					}
 					else
 					{
@@ -1489,7 +1485,7 @@ bool monst_spell_monst(int m_idx)
 					t_ptr->confused += randint0(4) + 4;
 
 #ifdef JP
-					mon_take_hit_mon(t_idx, damroll(8, 8), &fear, "ΤȴȤʤä", m_idx);
+					mon_take_hit_mon(t_idx, damroll(8, 8), &fear, "Τȴ̤Ȥʤä", m_idx);
 #else
 					mon_take_hit_mon(t_idx, damroll(8, 8), &fear, " collapses, a mindless husk.", m_idx);
 #endif
@@ -1548,7 +1544,7 @@ bool monst_spell_monst(int m_idx)
 					t_ptr->stunned += randint0(4) + 4;
 
 #ifdef JP
-					mon_take_hit_mon(t_idx, damroll(12, 15), &fear, "ΤȴȤʤä", m_idx);
+					mon_take_hit_mon(t_idx, damroll(12, 15), &fear, "Τȴ̤Ȥʤä", m_idx);
 #else
 					mon_take_hit_mon(t_idx, damroll(12, 15), &fear, " collapses, a mindless husk.", m_idx);
 #endif
@@ -2595,7 +2591,7 @@ bool monst_spell_monst(int m_idx)
 				break;
 			}
 
-			/* RF6_SUMMON_KIN */
+			/* RF6_S_KIN */
 			case 160+16:
 			{
 				if (known)
@@ -2610,6 +2606,7 @@ bool monst_spell_monst(int m_idx)
 						msg_format("%^s magically summons %s %s.", m_name, m_poss,
 									  ((r_ptr->flags1 & RF1_UNIQUE) ? "minions" : "kin"));
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -2645,6 +2642,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons Cyberdemons!", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -2677,6 +2675,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons help!", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -2709,6 +2708,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons monsters!", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -2742,6 +2742,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons ants.", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -2775,6 +2776,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons spiders.", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -2808,6 +2810,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons hounds.", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -2841,6 +2844,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons hydras.", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -2874,6 +2878,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons an angel!", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -2907,6 +2912,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons a hellish adversary!", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -2940,6 +2946,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons undead.", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -2973,6 +2980,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons a dragon!", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -3008,6 +3016,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons undead.", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -3043,6 +3052,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons ancient dragons!", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -3076,6 +3086,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons a hellish adversary!", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
@@ -3109,6 +3120,7 @@ bool monst_spell_monst(int m_idx)
 #else
 						msg_format("%^s magically summons special opponents!", m_name);
 #endif
+						sound(SOUND_SUMMON);
 					}
 					else
 					{
