@@ -925,7 +925,7 @@ void brand_weapon(int brand_type)
 #ifdef JP
 act = "ʤ륪ޤ줿";
 #else
-			act = "Nanka";
+			act = "is surrounded by holy light.";
 #endif
 
 			o_ptr->name2 = EGO_SLAY_EVIL;
@@ -3278,50 +3278,20 @@ void display_spell_list(void)
 	/* Erase window */
 	clear_from(0);
 
+	/* Snipers */
+	if (p_ptr->pclass == CLASS_SNIPER)
+	{
+		display_snipe_list();
+		return;
+	}
+
 	/* Warriors are illiterate */
 	if (!mp_ptr->spell_type) return;
 
 	/* Mindcrafter spell-list */
 	if (p_ptr->pclass == CLASS_MINDCRAFTER)
 	{
-		int             i;
-		int             y = 1;
-		int             x = 1;
-		int             plev = p_ptr->lev;
-		int             chance;
-		mindcraft_power spell;
-		char            comment[80];
-		char            psi_desc[80];
-
-		/* Display a list of spells */
-		prt("", y, x);
-#ifdef JP
-		put_str("̾", y, x + 5);
-		put_str("Lv   MP Ψ ", y, x + 35);
-#else
-		put_str("Name", y, x + 5);
-		put_str("Lv Mana Fail Info", y, x + 35);
-#endif
-
-		/* Dump the spells */
-		for (i = 0; i < MAX_MINDCRAFT_POWERS; i++)
-		{
-			/* Access the available spell */
-			spell = mindcraft_powers[i];
-			if (spell.min_lev > plev) break;
-
-			chance = get_spell_chance(spell.fail, spell.min_lev, spell.mana_cost);
-
-			/* Get info */
-			mindcraft_info(comment, i);
-
-			/* Dump the spell */
-			sprintf(psi_desc, "  %c) %-30s%2d %4d %3d%%%s",
-			    I2A(i), spell.name,
-			    spell.min_lev, spell.mana_cost, chance, comment);
-
-			Term_putstr(x, y + i + 1, -1, TERM_WHITE, psi_desc);
-		}
+		display_mind_list();
 		return;
 	}
 
@@ -3595,13 +3565,12 @@ static void spell_info(char *p, int spell, int realm)
 					case  7: sprintf(p, " »:%dd8", (3 + (plev - 5 ) / 4)); break;
 					case  8: strcpy (p, " :30+d25"); break;
 					case 10: strcpy (p, " :25+d25"); break;
-					case 11: strcpy (p, " :20+d20"); break;
-					case 15: sprintf(p, " :%d+d%d", plev, (20 + plev)); break;
+					case 13: strcpy (p, " :20+d20"); break;
+					case 16: sprintf(p, " :%d+d%d", plev, (20 + plev)); break;
 					case 18: sprintf(p, " »:%d+d%d", (plev * 3 / 2), plev * 2); break;
 					case 19: strcpy (p, " :20+d20"); break;
-					case 21: strcpy (p, " :25+d25"); break;
-					case 22: sprintf(p, " :%d+d25", (plev * 3)); break;
-					case 23: strcpy (p, " :25+d25"); break;
+					case 21: sprintf(p, " :%d+d25", (plev * 3)); break;
+					case 22: strcpy (p, " :25+d25"); break;
 					case 29: sprintf(p, " »:175+d%d", plev * 2); break;
 					case 31: strcpy (p, " :25+d25"); break;
 #else
@@ -3613,8 +3582,8 @@ static void spell_info(char *p, int spell, int realm)
 					case  7: sprintf(p, " dam %dd8", (3 + (plev - 5 ) / 4)); break;
 					case  8: strcpy (p, " dur 30+d25"); break;
 					case 10: strcpy (p, " dur 25+d25"); break;
-					case 11: strcpy (p, " dur 20+d20"); break;
-					case 15: sprintf(p, " dur %d+d%d", plev, (20 + plev)); break;
+					case 13: strcpy (p, " dur 20+d20"); break;
+					case 16: sprintf(p, " dur %d+d%d", plev, (20 + plev)); break;
 					case 18: sprintf(p, " dam %d+d%d", (plev * 3 / 2), plev * 2); break;
 					case 19: strcpy (p, " dur 20+d20"); break;
 					case 21: strcpy (p, " dur 25+d25"); break;
