@@ -1013,8 +1013,8 @@ struct player_type
 
 	u32b muta;         /* for Chaos mutation */
 
-	u32b xtra1;        /* Old mutation */
-	u32b xtra2;
+	u32b concent;      /* for sniper */
+	u32b xtra2;        /* Old mutation */
 
 	s16b word_recall;	/* Word of recall counter */
 
