@@ -199,6 +199,7 @@ s32b friend_align = 0;
 int leaving_quest = 0;
 
 bool superb_shot = FALSE;
+int snipe_type = SP_NONE;
 
 /*
  * Software options (set via the '=' command).  See "tables.c"
@@ -307,6 +308,8 @@ bool record_artifact;
 bool record_randart;
 bool record_unique;
 bool record_quest;
+bool dump_abilities;
+bool dump_messages;
 
 bool point_based;                       /* Point-based generation */
 bool delay_autoroll;                    /* Delay in autoroll */
@@ -1150,9 +1153,13 @@ u32b start_time;		/* Start time of Game */
 
 bool not_gain_energy = FALSE;   /* Gain energy flag */
 
-#ifdef CHUUKEI
+bool reset_concent = FALSE;   /* Concentration reset flag */
+
+/* for chuukei */
 bool chuukei_server;
 bool chuukei_client;
 char *server_name;
 int server_port;
-#endif
+
+/* for movie */
+bool browsing_movie;
