@@ -543,12 +543,7 @@ static void generate_area(int y, int x, bool border, bool corner)
 		else
 			init_flags = INIT_CREATE_DUNGEON;
 
-#ifdef JP
-		process_dungeon_file("t_info_j.txt", 0, 0, MAX_HGT, MAX_WID);
-#else
 		process_dungeon_file("t_info.txt", 0, 0, MAX_HGT, MAX_WID);
-#endif
-
 	}
 	else
 	{
@@ -648,12 +643,7 @@ void wilderness_gen(void)
 	panel_col_min = cur_wid;
 
 	/* Init the wilderness */
-#ifdef JP
-	process_dungeon_file("w_info_j.txt", 0, 0, max_wild_y, max_wild_x);
-#else
 	process_dungeon_file("w_info.txt", 0, 0, max_wild_y, max_wild_x);
-#endif
-
 
 	x = p_ptr->wilderness_x;
 	y = p_ptr->wilderness_y;
@@ -860,7 +850,7 @@ errr parse_line_wilderness(char *buf, int ymin, int xmin, int ymax, int xmax, in
 		/* Process "W:F:<letter>:<terrain>:<town>:<road>:<name> */
 		case 'F':
 		{
-			if ((num = tokenize(buf+4, 6, zz, 0)) > 1)
+			if ((num = tokenize(buf+4, 7, zz, 0)) > 1)
 			{
 
 				int index = zz[0][0];
@@ -889,6 +879,10 @@ errr parse_line_wilderness(char *buf, int ymin, int xmin, int ymax, int xmax, in
 					strcpy(w_letter[index].name, zz[5]);
 				else
 					w_letter[index].name[0] = 0;
+#ifdef JP
+				if (num > 6)
+					strcpy(w_letter[index].name, zz[6]);
+#endif
 			}
 			else
 			{
