@@ -168,7 +168,7 @@ static grouper group_item[] =
 
 	{ TV_LIFE_BOOK,     "Books (Life)" },
 	{ TV_SORCERY_BOOK,  "Books (Sorcery)" },
-	{ TV_MUSOU_BOOK,    "Books (Musou)" },
+	{ TV_MUSOU_BOOK,    "Books (Combat)" },
 
 	{ TV_CHEST,         "Chests" },
 	{ TV_FIGURINE,      "Magical Figurines" },
@@ -548,14 +548,16 @@ static flag_desc pval_flags1_desc[] =
 	{ TR1_INFRA,      "ֳ" },
 	{ TR1_TUNNEL,     "η" },
 	{ TR1_BLOWS,      "" },
-	{ TR1_SPEED,      "ԡ" }
+	{ TR1_SPEED,      "ԡ" },
+	{ TR1_MAGIC_MASTERY, "ˡƻ" }
 #else
 	{ TR1_STEALTH,    "Stealth" },
 	{ TR1_SEARCH,     "Searching" },
 	{ TR1_INFRA,      "Infravision" },
 	{ TR1_TUNNEL,     "Tunneling" },
 	{ TR1_BLOWS,      "Attacks" },
-	{ TR1_SPEED,      "Speed" }
+	{ TR1_SPEED,      "Speed" },
+	{ TR1_MAGIC_MASTERY, "Magic device" }
 #endif
 };
 
@@ -1202,7 +1204,6 @@ static void object_analyze(object_type *o_ptr, obj_desc_list *desc_ptr)
 	desc_ptr->activation = item_activation(o_ptr);
 }
 
-
 static void print_header(void)
 {
 	char buf[80];
@@ -1414,6 +1415,64 @@ static void spoiler_print_art(obj_desc_list *art_ptr)
 }
 
 
+void dump_object(FILE *fp, object_type *o_ptr)
+{
+	char buf[80];
+	obj_desc_list obj;
+	pval_info_type *pval_ptr = &obj.pval_info;
+
+	fff = fp;
+	object_analyze(o_ptr, &obj);
+
+	/* An "empty" pval description indicates that the pval affects nothing */
+	if (pval_ptr->pval_desc[0])
+	{
+		/* Mention the effects of pval */
+#ifdef JP
+		sprintf(buf, "  %sν:", pval_ptr->pval_desc);
+#else
+		sprintf(buf, "  %s to", pval_ptr->pval_desc);
+#endif
+		spoiler_outlist(buf, pval_ptr->pval_affects, ITEM_SEP);
+	}
+
+	/* Now deal with the description lists */
+
+#ifdef JP
+	spoiler_outlist("  :", obj.slays, ITEM_SEP);
+
+	spoiler_outlist("  °:", obj.brands, LIST_SEP);
+
+	spoiler_outlist("  ȱ:", obj.immunities, ITEM_SEP);
+
+	spoiler_outlist("  :", obj.resistances, ITEM_SEP);
+
+	spoiler_outlist("  ݻ:", obj.sustains, ITEM_SEP);
+#else
+	spoiler_outlist("  Slay", obj.slays, ITEM_SEP);
+
+	spoiler_outlist("  ", obj.brands, LIST_SEP);
+
+	spoiler_outlist("  Immunity to", obj.immunities, ITEM_SEP);
+
+	spoiler_outlist("  Resist", obj.resistances, ITEM_SEP);
+
+	spoiler_outlist("  Sustain", obj.sustains, ITEM_SEP);
+#endif
+	spoiler_outlist("  ", obj.misc_magic, LIST_SEP);
+
+
+	/* Write out the possible activation at the primary indention level */
+	if (obj.activation)
+	{
+#ifdef JP
+		fprintf(fff, "%s  ȯư: %s\n", INDENT1, obj.activation);
+#else
+		fprintf(fff, "%s  Activates for %s\n", INDENT1, obj.activation);
+#endif
+	}
+}
+
 /*
  * Hack -- Create a "forged" artifact
  */
