@@ -558,9 +558,9 @@ static void wiz_display_item(object_type *o_ptr)
 	prt("+------------FLAGS1------------+", 10, j);
 	prt("AFFECT........SLAY........BRAND.", 11, j);
 	prt("              cvae      xsqpaefc", 12, j);
-	prt("siwdcc  ssidsahanvudotgddhuoclio", 13, j);
-	prt("tnieoh  trnipttmiinmrrnrrraiierl", 14, j);
-	prt("rtsxna..lcfgdkcpmldncltggpksdced", 15, j);
+	prt("siwdccm ssidsahanvudotgddhuoclio", 13, j);
+	prt("tnieohd trnipttmiinmrrnrrraiierl", 14, j);
+	prt("rtsxnav.lcfgdkcpmldncltggpksdced", 15, j);
 	prt_binary(f1, 16, j);
 
 	prt("+------------FLAGS2------------+", 17, j);
@@ -664,7 +664,7 @@ static tval_desc tvals[] =
 	{ TV_ROD,               "Rod"                  },
 	{ TV_LIFE_BOOK,         "Life Spellbook"       },
 	{ TV_SORCERY_BOOK,      "Sorcery Spellbook"    },
-	{ TV_MUSOU_BOOK,        "Musou  Spellbook"     },
+	{ TV_MUSOU_BOOK,        "Combat Spellbook"     },
 	{ TV_SPIKE,             "Spikes"               },
 	{ TV_DIGGING,           "Digger"               },
 	{ TV_CHEST,             "Chest"                },
