@@ -361,7 +361,8 @@ static void prt_status(void)
 	if (p_ptr->tim_invis) ADD_FLG(BAR_SENSEUNSEEN);
 
 	/* Timed esp */
-	if (p_ptr->tim_esp) ADD_FLG(BAR_TELEPATHY);
+	if ((p_ptr->tim_esp) ||
+	    (p_ptr->concent >= CONCENT_TELE_THRESHOLD)) ADD_FLG(BAR_TELEPATHY);
 
 	/* Timed regenerate */
 	if (p_ptr->tim_regen) ADD_FLG(BAR_REGENERATION);
@@ -370,7 +371,8 @@ static void prt_status(void)
 	if (p_ptr->tim_infra) ADD_FLG(BAR_INFRAVISION);
 
 	/* Timed radar-eye */
-	if (p_ptr->tim_radar) ADD_FLG(BAR_RADAREYE);
+	if ((p_ptr->tim_radar) ||
+	    (p_ptr->concent >= CONCENT_RADAR_THRESHOLD)) ADD_FLG(BAR_RADAREYE);
 
 	/* Protection from evil */
 	if (p_ptr->protevil) ADD_FLG(BAR_PROTEVIL);
@@ -2024,6 +2026,7 @@ static void calc_mana(void)
 			/* Normal gloves hurt mage-type spells */
 			if (o_ptr->k_idx &&
 				!(f2 & (TR2_FREE_ACT)) &&
+				!(f1 & (TR1_MAGIC_MASTERY)) &&
 				!((f1 & (TR1_DEX)) && (o_ptr->pval > 0)))
 			{
 				/* Encumbered */
@@ -2095,6 +2098,9 @@ static void calc_mana(void)
 					break;
 				}
 
+				case CLASS_SNIPER:
+					break;
+
 				/* For new classes created, but not yet added to this formula. */
 				default:
 				{
@@ -2425,6 +2431,7 @@ static sint add_special_melee_skill(byte pclass, s16b weight, object_type *o_ptr
 		*weapons without penalty at 50th level. */
 		case CLASS_RANGER:
 		case CLASS_ARCHER:
+		case CLASS_SNIPER:
 		{
 			add_skill = 25 + (1 * p_ptr->lev / 2) - (weight / 5);
 			if (add_skill > 0) add_skill = 0;
@@ -2509,6 +2516,14 @@ static sint add_special_missile_skill(byte pclass)
 			break;
 		}
 
+		case CLASS_SNIPER:
+		{
+			if (p_ptr->tval_ammo == TV_BOLT)
+			{
+				add_skill = 10 + p_ptr->lev / 5;
+			}
+		}
+
 		/* Monks get a small bonus with slings. */
 		case CLASS_MONK:
 		{
@@ -2695,6 +2710,10 @@ void calc_bonuses(void)
 			if (p_ptr->lev > 29) p_ptr->resist_fear = TRUE;
 			if (p_ptr->lev > 44) p_ptr->regenerate = TRUE;
 			break;
+		case CLASS_RANGER:
+			if (!(monk_heavy_armor()))
+				p_ptr->pspeed += (p_ptr->lev) / 10;
+			break;
 		case CLASS_PALADIN:
 			if (p_ptr->lev > 39) p_ptr->resist_fear = TRUE;
 			break;
@@ -3054,6 +3073,9 @@ void calc_bonuses(void)
 		if (f1 & (TR1_CON)) p_ptr->stat_add[A_CON] += (s16b) o_ptr->pval;
 		if (f1 & (TR1_CHR)) p_ptr->stat_add[A_CHR] += (s16b) o_ptr->pval;
 
+		/* Affect magic devices */
+		if (f1 & (TR1_MAGIC_MASTERY)) p_ptr->skill_dev += (o_ptr->pval * 8);
+
 		/* Affect stealth */
 		if (f1 & (TR1_STEALTH)) p_ptr->skill_stl += (s16b) o_ptr->pval;
 
@@ -3594,7 +3616,7 @@ void calc_bonuses(void)
 		{
 			/* Extra shots */
 			p_ptr->num_fire += (extra_shots * 100);
-
+#if 0
 			/* Hack -- Rangers love Bows */
 			if ((p_ptr->pclass == CLASS_RANGER) &&
 			    (p_ptr->tval_ammo == TV_ARROW))
@@ -3608,7 +3630,7 @@ void calc_bonuses(void)
 			{
 				p_ptr->num_fire += (p_ptr->lev * 2);
 			}
-
+#endif
 			/* Hack -- Rogues love Slings */
 			if ((p_ptr->pclass == CLASS_ROGUE) &&
 			    (p_ptr->tval_ammo == TV_SHOT))
@@ -3630,7 +3652,9 @@ void calc_bonuses(void)
 			/* Hack -- Archers love shooting */
 			if (p_ptr->pclass == CLASS_ARCHER)
 			{
-				p_ptr->num_fire += (p_ptr->lev * 6);
+				if (p_ptr->tval_ammo == TV_ARROW) p_ptr->num_fire += (p_ptr->lev * 6);
+				else if ((p_ptr->tval_ammo == TV_BOLT) || (p_ptr->tval_ammo == TV_SHOT))
+					p_ptr->num_fire += (p_ptr->lev * 4);
 			}
 		}
 	}
@@ -3702,6 +3726,9 @@ void calc_bonuses(void)
 		/* Warrior gets one extra attack */
 		if (p_ptr->pclass == CLASS_WARRIOR) p_ptr->num_blow++;
 
+		/* Ranger gets one extra attack with a light weapon */
+		if ((p_ptr->pclass == CLASS_RANGER) && (o_ptr->weight <= 70)) p_ptr->num_blow++;
+
 		/* Archaeologit gets extra attacks with digging */
 		if ((p_ptr->pclass == CLASS_ARCHAEOLOGIST) &&
 			(o_ptr->tval == TV_DIGGING))
@@ -3798,7 +3825,6 @@ void calc_bonuses(void)
 		monk_armour_aux = TRUE;
 	}
 
-
 	/* Affect Skill -- stealth (bonus one) */
 	p_ptr->skill_stl += 1;
 
@@ -4430,8 +4456,19 @@ bool monk_empty_hands(void)
 bool monk_heavy_armor(void)
 {
 	u16b monk_arm_wgt = 0;
+	u16b max = 0;
 
-	if (p_ptr->pclass != CLASS_MONK) return FALSE;
+	switch(p_ptr->pclass)
+	{
+		case CLASS_RANGER:
+			max = 250 + p_ptr->lev * 4;
+			break;
+		case CLASS_MONK:
+			max = 100 + p_ptr->lev * 4;
+			break;
+		default:
+			return 0;
+	}
 
 	/* Weight the armor */
 	monk_arm_wgt += inventory[INVEN_BODY].weight;
@@ -4441,7 +4478,7 @@ bool monk_heavy_armor(void)
 	monk_arm_wgt += inventory[INVEN_HANDS].weight;
 	monk_arm_wgt += inventory[INVEN_FEET].weight;
 
-	return (monk_arm_wgt > (100 + (p_ptr->lev * 4)));
+	return (monk_arm_wgt > max);
 }
 
 /* Count the number of random quests chosen */
